# encoding: UTF-8

module Dezmo
module SaveAndCopyAsSKPVersion
  extend self
  @@loaded = false unless defined?(@@loaded)
  
  SU_VER ||= {
       "SU_3" => Sketchup::Model::VERSION_3,
       "SU_4" => Sketchup::Model::VERSION_4,
       "SU_5" => Sketchup::Model::VERSION_5,
       "SU_6" => Sketchup::Model::VERSION_6
  }
  
  def m_path
    return "" unless Sketchup.active_model
    Sketchup.active_model.path
  end
  
  def new_path( input = @vers )
    # m_path.delete_suffix('.skp')<<"-#{input}.skp"
    a = m_path
    a.slice!(-4..-1) if a[-4,4] == ".skp"
    a<<"-#{input}.skp"
  end
  
  def save_copy_as( path = new_path )
    saved = Sketchup.active_model.save_copy(path, SU_VER[@vers])
    UI.messagebox("模型不能复制到自身。") if !saved
  end
  
  def save_over( path = m_path )
    saved = Sketchup.active_model.save(path, SU_VER[@vers])
    UI.messagebox("无法保存模型。") if !saved
  end
  
  def save_as_interactive( copy = true )
    return UI.messagebox("保存副本前必须先保存模型。 ") if copy && m_path.empty?
    
    prompt = ["Sketchup version:"]
    default =  [ @vers ]
    list = [SU_VER.keys.join("|")]
    input = UI.inputbox(prompt, default, list, "选择 Sketchup 版本")
    return unless input
    @vers = input[0]
    path_new = copy ? new_path : m_path
    text = copy ? "将副本保存为 Sketchup 文件 #{input[0]}" : "另存为 Sketchup #{input[0]}"
    path_to_save_to = UI.savepanel(text, path_new)
    return unless path_to_save_to
    Sketchup.write_default("Dezmo_保存旧版本", "默认版本", @vers)
    copy ? save_copy_as(path_to_save_to) : save_over( path_to_save_to )
  end
  
  def donate
    status = UI.openURL("https://paypal.me/DezmoHU")
  end
  
  unless @@loaded

    [7,8,2013,2014,2015,2016,2017,2018,2019,2020,2021].each{ |n|
      ver = Sketchup.version.to_i
      ver += 2000 if ver > 8
      break if n == ver
      SU_VER["SU_#{n}"] = Sketchup::Model.const_get("VERSION_#{n}")
    }
    
    @vers = Sketchup.read_default("Dezmo_保存旧版本", "默认版本", "SU_8")

    TipNo1 = "在保存副本之前，必须先保存模型。 "
    # TipNo11 = "Use menu: 'Save A Copy...(Select)' first."
    TipNo2 = "在保存到旧版本之前，必须先保存模型。"
    # TipNo21 = "Use menu: 'Save actual model...(Select)' first."
    TipY1 = " “另存为 ”旧版 Sketchup（选择版本） "
    TipY2 = " 将模型保存为 Sketchup 旧版本（选择版本） "
    
    cmd1 = UI::Command.new("将副本另存为版本...（选择版本）"){
      save_as_interactive( true )
    }
    cmd1.tooltip = cmd1.menu_text
    cmd1.status_bar_text = TipY1
    cmd1.set_validation_proc{
      if m_path.empty?
        cmd1.status_bar_text = TipNo1
        MF_GRAYED
      else
        cmd1.status_bar_text = TipY1
        MF_ENABLED
      end
    }
    
    cmd11 = UI::Command.new("将副本另存为版本：#{@vers}"){
      save_copy_as()
    }
    cmd11.tooltip = cmd11.menu_text
    cmd11.set_validation_proc{
      if !m_path.empty? && @vers
        cmd11.status_bar_text = " #{new_path}"
        MF_ENABLED
      else
        cmd11.status_bar_text = TipNo1
        MF_GRAYED
      end
    }
    
    cmd2 = UI::Command.new("将模型保存为版本...（选择版本）"){
      save_as_interactive( false )
    }
    cmd2.tooltip = cmd2.menu_text
    cmd2.status_bar_text = TipY2
    
    cmd21 = UI::Command.new("将模型保存为版本：#{@vers}"){
      save_over()
    }
    cmd21.tooltip = cmd21.menu_text
    cmd21.set_validation_proc{
      if !m_path.empty? && @vers
        cmd21.status_bar_text = " #{m_path}"
        MF_ENABLED
      else
        cmd21.status_bar_text = TipNo2
        MF_GRAYED
      end
    }
    
    cmd7 = UI::Command.new("捐款, ©Dezmo"){
      donate
    }
    cmd7.tooltip = cmd7.menu_text
    cmd7.status_bar_text = "通过啤酒、饼干......为我捐款： \nPayPal 链接将在您的浏览器中打开。"
    
    submenu = UI.menu("File").add_submenu("保存到 SketchUp 旧版本")
    submenu.add_item cmd1
    submenu.add_item cmd11
    submenu.add_item cmd2
    submenu.add_item cmd21
    submenu.add_item cmd7
    
    cmd1.small_icon = File.join(File.dirname(__FILE__), "/save_ci.png")
    cmd1.large_icon = File.join(File.dirname(__FILE__), "/save_ci.png")
    
    cmd11.small_icon = File.join(File.dirname(__FILE__), "/save_cd.png")
    cmd11.large_icon = File.join(File.dirname(__FILE__), "/save_cd.png")
    
    
    cmd2.small_icon = File.join(File.dirname(__FILE__), "/save_oi.png")
    cmd2.large_icon = File.join(File.dirname(__FILE__), "/save_oi.png")
    
    
    cmd21.small_icon = File.join(File.dirname(__FILE__), "/save_od.png")
    cmd21.large_icon = File.join(File.dirname(__FILE__), "/save_od.png")
    
    
    cmd7.small_icon = File.join(File.dirname(__FILE__), "/beer.png")
    cmd7.large_icon = File.join(File.dirname(__FILE__), "/beer.png")
    
    Toolbar1 = UI::Toolbar.new("保存到 SketchUp 旧版本。 ©Dezmo")
    Toolbar1.add_item(cmd1)
    Toolbar1.add_item(cmd11)
    Toolbar1.add_separator
    Toolbar1.add_item(cmd2)
    Toolbar1.add_item(cmd21)
    Toolbar1.add_separator
    Toolbar1.add_item(cmd7)
    Toolbar1.restore
    
    @@loaded = true
  end
end
end